.. _examples_toplevel:

Examples
========

The SQLAlchemy distribution includes a variety of code examples illustrating a select set of patterns, some typical and some not so typical.   All are runnable and can be found in the ``/examples`` directory of the distribution.   Each example contains a README in its ``__init__.py`` file, each of which are listed below.

Additional SQLAlchemy examples, some user contributed, are available on the wiki at `<http://www.sqlalchemy.org/trac/wiki/UsageRecipes>`_.

.. _examples_adjacencylist:

Adjacency List
--------------

Location: /examples/adjacency_list/

.. automodule:: adjacency_list

Associations
------------

Location: /examples/association/

.. automodule:: association


.. _examples_instrumentation:

Attribute Instrumentation
-------------------------

Location: /examples/custom_attributes/

.. automodule:: custom_attributes

.. _examples_caching:

Beaker Caching
--------------

Location: /examples/beaker_caching/

.. automodule:: beaker_caching

Derived Attributes
------------------

Location: /examples/derived_attributes/

.. automodule:: derived_attributes


Directed Graphs
---------------

Location: /examples/graphs/

.. automodule:: graphs

Dynamic Relations as Dictionaries
----------------------------------

Location: /examples/dynamic_dict/

.. automodule:: dynamic_dict

.. _examples_sharding:

Horizontal Sharding
-------------------

Location: /examples/sharding

.. automodule:: sharding

Inheritance Mappings
--------------------

Location: /examples/inheritance/

.. automodule:: inheritance

Large Collections
-----------------

Location: /examples/large_collection/

.. automodule:: large_collection

Nested Sets
-----------

Location: /examples/nested_sets/

.. automodule:: nested_sets

Polymorphic Associations
------------------------

Location: /examples/poly_assoc/

.. automodule:: poly_assoc

PostGIS Integration
-------------------

Location: /examples/postgis

.. automodule:: postgis

Versioned Objects
-----------------

Location: /examples/versioning

.. automodule:: versioning

Vertical Attribute Mapping
--------------------------

Location: /examples/vertical

.. automodule:: vertical

.. _examples_xmlpersistence:

XML Persistence
---------------

Location: /examples/elementtree/

.. automodule:: elementtree
